@@ -249,7 +249,7 @@ mod tests {
 
     #[test]
     fn buildaxes_works() {
-        let data = read(&Path::new("tests").join(Path::new("DP14.csv"))).expect("");
+        let data = read(&"tests", &"DP14").expect("");
 
         let h = Heuristics {
             strategy: vec![0],
@@ -263,7 +263,7 @@ mod tests {
             vec![8, 10, 8, 10, 10, 10, 10, 10, 8, 10, 8, 10, 10, 10, 10, 10]
         );
 
-        let data = read(&Path::new("tests").join(Path::new("DP1.csv"))).expect("");
+        let data = read(&"tests", &"DP1").expect("");
         assert_eq!(data.candidates[0].actual_error, 8);
         assert_eq!(data.candidates[1].actual_error, 5);
 
@@ -277,7 +277,7 @@ mod tests {
             .map(|q| q.corrs)
             .any(|x| x == vec![Answer::F, Answer::V, Answer::F, Answer::F, Answer::V]));
 
-        let data = read(&Path::new("tests").join(Path::new("DP1_swap.csv"))).expect("");
+        let data = read(&"tests", &"DP1_swap").expect("");
         assert_eq!(data.candidates[0].actual_error, 5);
         assert_eq!(data.candidates[1].actual_error, 8);
 
@@ -294,10 +294,8 @@ mod tests {
 
     #[test]
     fn axes_non_increasing_works() {
-        let data_on =
-            read(&Path::new("tests").join(Path::new("DP1_5c_suggestions_on.csv"))).expect("");
-        let data_off =
-            read(&Path::new("tests").join(Path::new("DP1_5c_suggestions_off.csv"))).expect("");
+        let data_on = read(&"tests", &"DP1_5c_suggestions_on").expect("");
+        let data_off = read(&"tests", &"DP1_5c_suggestions_off").expect("");
 
         let mut h = Heuristics {
             strategy: vec![0],
